@@ -4,13 +4,15 @@
 extern crate termion;
 
 pub mod bars;
-pub mod macros;
-pub mod prelude;
-pub(crate) mod wrapper;
-pub(crate) mod manager;
 pub(crate) mod isbar;
+pub(crate) mod iterator;
+pub mod macros;
+pub(crate) mod manager;
+pub mod prelude;
 pub(crate) mod utils;
+pub(crate) mod wrapper;
 
+pub use isbar::subsets as bar_subsets;
+pub use isbar::IsBar;
 pub use manager::BarManager;
 pub use wrapper::BarWrapper;
-pub use isbar::IsBar;
\ No newline at end of file
